@@ -1,4 +1,5 @@
 __all__ = ['base', 'scheduler', 'queue']
 
 from scheduler import Scheduler # convenience
-from queue import Queue # more convenience
+from queue import Queue
+from base import ContentType
